@@ -1,22 +1,9 @@
-/**************************************************************************
- * Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>                    *
- * Copyright (C) 2007 Will Stephenson <wstephenson@kde.org>               *
- *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 2         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program; if not, write to the Free Software            *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA          *
- * 02110-1301, USA.                                                       *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ * SPDX-FileCopyrightText: 2007 Will Stephenson <wstephenson@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "MenuModel.h"
 
@@ -125,7 +112,12 @@ QVariant MenuModel::data(const QModelIndex &index, int role) const
         theData.setValue(mi->keywords().join(QString()));
         break;
     case MenuModel::UserSortRole:
-        theData.setValue(QStringLiteral("%1").arg(QString::number(mi->weight()), 5, QLatin1Char('0')));
+        //Category owners are always before everything else, regardless of weight
+        if (mi->isCategoryOwner()) {
+            theData.setValue(QStringLiteral("%1").arg(QString::number(mi->weight()), 5, QLatin1Char('0')));
+        } else {
+            theData.setValue(QStringLiteral("1%1").arg(QString::number(mi->weight()), 5, QLatin1Char('0')));
+        }
         break;
     case MenuModel::DepthRole: {
         MenuItem *candidate = mi;
@@ -135,6 +127,13 @@ QVariant MenuModel::data(const QModelIndex &index, int role) const
             candidate = candidate->parent();
             ++depth;
         }
+
+        MenuItem *parent = mi->parent();
+        // Items that are in a category with an owner are one level deeper,
+        // except the owner
+        if (parent && parent->menu() && !parent->item().service()->library().isEmpty() && !mi->isCategoryOwner()) {
+            ++depth;
+        }
         theData.setValue(depth);
         break;
     }
