@@ -1,22 +1,9 @@
-/*****************************************************************************
- *   Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>                     *
- *   Copyright (C) 2009 by Mathias Soeken <msoeken@informatik.uni-bremen.de> *
- *                                                                           *
- *   This program is free software; you can redistribute it and/or modify    *
- *   it under the terms of the GNU General Public License as published by    *
- *   the Free Software Foundation; either version 2 of the License, or       *
- *   (at your option) any later version.                                     *
- *                                                                           *
- *   This program is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
- *   GNU General Public License for more details.                            *
- *                                                                           *
- *   You should have received a copy of the GNU General Public License       *
- *   along with this program; if not, write to the                           *
- *   Free Software Foundation, Inc.,                                         *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA            *
- *****************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *   SPDX-FileCopyrightText: 2009 Mathias Soeken <msoeken@informatik.uni-bremen.de>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef MODULE_VIEW_H
 #define MODULE_VIEW_H
@@ -25,6 +12,8 @@
 #include <QModelIndex>
 #include <QWidget>
 
+#include "systemsettingsview_export.h"
+
 class KAboutData;
 class KCModuleInfo;
 class KCModuleProxy;
@@ -46,7 +35,7 @@ class KPageWidgetItem;
  * @author Mathias Soeken <msoeken@informatik.uni-bremen.de>
  * @author Ben Cooksley <bcooksley@kde.org>
  */
-class ModuleView : public QWidget
+class SYSTEMSETTINGSVIEW_EXPORT ModuleView : public QWidget
 {
     Q_OBJECT
 
